@@ -1,11 +1,15 @@
 context("test_list_fields")
 
 test_that("we can search for a field name", {
-  needs_api()
-  
-  if(TRUE) skip("skip test_list_fields")
-  
   
   df <- list_fields("Temp")
   expect_is(df, "data.frame")
-})
\ No newline at end of file
+})
+
+test_that("we can browse docs", {
+  
+  df <- docs()
+  expect_is(df, "data.frame")
+  df <- docs("fecundity")
+  expect_is(df, "data.frame")
+})
